numpy_support Package
=====================

:mod:`numpy_support` Package
----------------------------

.. automodule:: numba.support.numpy_support
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`slicenodes` Module
------------------------

.. automodule:: numba.support.numpy_support.slicenodes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sliceutils` Module
------------------------

.. automodule:: numba.support.numpy_support.sliceutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`slicing` Module
---------------------

.. automodule:: numba.support.numpy_support.slicing
    :members:
    :undoc-members:
    :show-inheritance:

